Use Cases — Translate Toolkit 3.3.4 documentation

# Use Cases

- Migrating an older version of your translations to the latest templates

- Checking for technical errors in your translations

- Translating using only a spreadsheet (a look at the whole roundtrip from PO to CSV and back)

- Creating OpenOffice.org POT files

- Checking for inconsistencies in your translations

- Creating a terminology list from your existing translations

- Running the tools on Microsoft Windows

- Using `phase` for the complete translation roundtrip

- Cleanup translator comments

- Creating Mozilla POT files

- Document translation